@@ -56,6 +56,8 @@ const char * g_vt_red = "\x1B[91m";
 const char * g_vt_kcyn = "\x1B[36m";
 const char * g_vt_boldwhite = "\x1B[97m";
 
+size_t g_max_process_width = 0;
+
 void clean_vt_color() noexcept
 {
 	g_vt_yellow = "";
@@ -83,8 +85,6 @@ vector<string> g_usb_serial_no_filter;
 int g_verbose = 0;
 static bool g_start_usb_transfer;
 
-bmap_mode g_bmap_mode = bmap_mode::Default;
-
 class AutoCursor
 {
 public:
@@ -325,9 +325,11 @@ string build_process_bar(size_t width, size_t pos, size_t total)
 
 void print_auto_scroll(string str, size_t len, size_t start)
 {
+	g_max_process_width = max(str.size(), g_max_process_width);
+	g_max_process_width = min(g_max_process_width, len);
 	if (str.size() <= len)
 	{
-		str.resize(len, ' ');
+		str.resize(g_max_process_width, ' ');
 		cout << str;
 		return;
 	}
@@ -337,6 +339,13 @@ void print_auto_scroll(string str, size_t len, size_t start)
 	else
 		start = 0;
 
+	if (str.size() >= len){
+		str.resize(len - 1);
+		str[str.size() - 1] = '.';
+		str[str.size() - 2] = '.';
+		str[str.size() - 3] = '.';
+	}
+
 	string s = str.substr(start, len);
 	s.resize(len, ' ');
 	cout << s;
@@ -593,6 +602,10 @@ void print_oneline(string str)
 	if (w <= 3)
 		return;
 
+	if (g_max_process_width == 0){
+		g_max_process_width = min(str.size(), w);
+	}
+
 	if (str.size() >= w)
 	{
 		str.resize(w - 1);
@@ -602,7 +615,7 @@ void print_oneline(string str)
 	}
 	else
 	{
-		str.resize(w, ' ');
+		str.resize(g_max_process_width, ' ');
 	}
 	cout << str << endl;
 
@@ -656,7 +669,7 @@ int progress(uuu_notify nt, void *p)
 		else
 		{
 			string_ex str;
-			str.format("\rSuccess %d    Failure %d    ", g_overall_okay, g_overall_failure);
+			str.format("\rSuccess %d    Failure %d             ", g_overall_okay, g_overall_failure);
 
 			if (g_map_path_nt.empty())
 				str += "Wait for Known USB Device Appear...";
@@ -962,11 +975,12 @@ int main(int argc, char **argv)
 			else if (s == "-v")
 			{
 				g_verbose = 1;
+				uuu_set_debug_level(LIBUUU_DETAIL);
 			}
 			else if (s == "-V")
 			{
 				g_verbose = 1;
-				uuu_set_debug_level(2);
+				uuu_set_debug_level(LIBUUU_DETAIL | 2);
 			}else if (s == "-dry")
 			{
 				dryrun = 1;
@@ -1020,11 +1034,11 @@ int main(int argc, char **argv)
 			}
 			else if (s == "-bmap")
 			{
-				g_bmap_mode = bmap_mode::Force;
+				uuu_set_bmap_mode(bmap_mode::Force);
 			}
 			else if (s == "-no-bmap")
 			{
-				g_bmap_mode = bmap_mode::Ignore;
+				uuu_set_bmap_mode(bmap_mode::Ignore);
 			}
 			else if (s == "-e")
 			{
